@@ -180,14 +180,16 @@ dialog_show_callback (GtkWidget *widget, gpointer callback_data)
 
 	password_dialog = AMMONITE_LOGIN_DIALOG (callback_data);
 
-	if (password_dialog->details->username_should_focus) {
-		/* Move the focus to the username entry */
-		ammonite_caption_table_entry_grab_focus (AMMONITE_CAPTION_TABLE (password_dialog->details->table), 
-							 CAPTION_TABLE_USERNAME_ROW);
-	} else {
-		/* Move the focus to the password entry */
-		ammonite_caption_table_entry_grab_focus (AMMONITE_CAPTION_TABLE (password_dialog->details->table), 
-							 CAPTION_TABLE_PASSWORD_ROW);
+	if (NULL != password_dialog->details->table) {
+		if (password_dialog->details->username_should_focus) {
+			/* Move the focus to the username entry */
+			ammonite_caption_table_entry_grab_focus (AMMONITE_CAPTION_TABLE (password_dialog->details->table), 
+								 CAPTION_TABLE_USERNAME_ROW);
+		} else {
+			/* Move the focus to the password entry */
+			ammonite_caption_table_entry_grab_focus (AMMONITE_CAPTION_TABLE (password_dialog->details->table), 
+								 CAPTION_TABLE_PASSWORD_ROW);
+		}
 	}
 }
 
@@ -280,8 +282,10 @@ ammonite_login_dialog_new	(EazelProxy_AuthnPromptKind prompt_kind,
 		password_dialog->details->button_mode = BUTTON_MODE_FORGOTPW;
 	}
 
-	gnome_dialog_set_default (GNOME_DIALOG (password_dialog), 
-		button_mappings [BUTTON_OK][password_dialog->details->button_mode] );
+	if (button_mappings [BUTTON_OK][password_dialog->details->button_mode] != -1) {
+		gnome_dialog_set_default (GNOME_DIALOG (password_dialog), 
+			button_mappings [BUTTON_OK][password_dialog->details->button_mode] );
+	}
 	
 	/* Setup the dialog */
 	gtk_window_set_policy (GTK_WINDOW (password_dialog), 
