@@ -22,38 +22,38 @@
    Authors: Ramiro Estrugo <ramiro@eazel.com>
 */
 
-#ifndef NAUTILUS_CAPTION_TABLE_H
-#define NAUTILUS_CAPTION_TABLE_H
+#ifndef AMMONITE_CAPTION_TABLE_H
+#define AMMONITE_CAPTION_TABLE_H
 
 #include <gtk/gtktable.h>
 #include <gnome.h>
 
 /*
- * NautilusCaptionTable is a GtkTable sublass that allows you to painlessly
+ * AmmoniteCaptionTable is a GtkTable sublass that allows you to painlessly
  * create tables of nicely aligned captions.
  */
 
 BEGIN_GNOME_DECLS
 
-#define NAUTILUS_TYPE_CAPTION_TABLE			(nautilus_caption_table_get_type ())
-#define NAUTILUS_CAPTION_TABLE(obj)		(GTK_CHECK_CAST ((obj), NAUTILUS_TYPE_CAPTION_TABLE, NautilusCaptionTable))
-#define NAUTILUS_CAPTION_TABLE_CLASS(klass)	(GTK_CHECK_CLASS_CAST ((klass), NAUTILUS_TYPE_CAPTION_TABLE, NautilusCaptionTableClass))
+#define NAUTILUS_TYPE_CAPTION_TABLE			(ammonite_caption_table_get_type ())
+#define AMMONITE_CAPTION_TABLE(obj)		(GTK_CHECK_CAST ((obj), NAUTILUS_TYPE_CAPTION_TABLE, AmmoniteCaptionTable))
+#define AMMONITE_CAPTION_TABLE_CLASS(klass)	(GTK_CHECK_CLASS_CAST ((klass), NAUTILUS_TYPE_CAPTION_TABLE, AmmoniteCaptionTableClass))
 #define NAUTILUS_IS_CAPTION_TABLE(obj)		(GTK_CHECK_TYPE ((obj), NAUTILUS_TYPE_CAPTION_TABLE))
 #define NAUTILUS_IS_CAPTION_TABLE_CLASS(klass)	(GTK_CHECK_CLASS_TYPE ((klass), NAUTILUS_TYPE_CAPTION_TABLE))
 
 
-typedef struct _NautilusCaptionTable		NautilusCaptionTable;
-typedef struct _NautilusCaptionTableClass	NautilusCaptionTableClass;
-typedef struct _NautilusCaptionTableDetail	NautilusCaptionTableDetail;
+typedef struct _AmmoniteCaptionTable		AmmoniteCaptionTable;
+typedef struct _AmmoniteCaptionTableClass	AmmoniteCaptionTableClass;
+typedef struct _AmmoniteCaptionTableDetail	AmmoniteCaptionTableDetail;
 
-struct _NautilusCaptionTable
+struct _AmmoniteCaptionTable
 {
 	GtkTable table;
 
-	NautilusCaptionTableDetail *detail;
+	AmmoniteCaptionTableDetail *detail;
 };
 
-struct _NautilusCaptionTableClass
+struct _AmmoniteCaptionTableClass
 {
 	GtkTableClass parent_class;
 
@@ -61,30 +61,30 @@ struct _NautilusCaptionTableClass
 	void (*tab_out) (GtkWidget *caption_table);
 };
 
-GtkType    nautilus_caption_table_get_type           (void);
-GtkWidget* nautilus_caption_table_new                (guint                 num_rows);
-void       nautilus_caption_table_set_row_info       (NautilusCaptionTable *caption_table,
+GtkType    ammonite_caption_table_get_type           (void);
+GtkWidget* ammonite_caption_table_new                (guint                 num_rows);
+void       ammonite_caption_table_set_row_info       (AmmoniteCaptionTable *caption_table,
 						      guint                 row,
 						      const char           *label_text,
 						      const char           *entry_text,
 						      gboolean              entry_visibility,
 						      gboolean              entry_readonly);
-void       nautilus_caption_table_set_entry_text     (NautilusCaptionTable *caption_table,
+void       ammonite_caption_table_set_entry_text     (AmmoniteCaptionTable *caption_table,
 						      guint                 row,
 						      const char           *entry_text);
-void       nautilus_caption_table_set_entry_readonly (NautilusCaptionTable *caption_table,
+void       ammonite_caption_table_set_entry_readonly (AmmoniteCaptionTable *caption_table,
 						      guint                 row,
 						      gboolean              readonly);
-void       nautilus_caption_table_entry_grab_focus   (NautilusCaptionTable *caption_table,
+void       ammonite_caption_table_entry_grab_focus   (AmmoniteCaptionTable *caption_table,
 						      guint                 row);
-char*      nautilus_caption_table_get_entry_text     (NautilusCaptionTable *caption_table,
+char*      ammonite_caption_table_get_entry_text     (AmmoniteCaptionTable *caption_table,
 						      guint                 row);
-guint      nautilus_caption_table_get_num_rows       (NautilusCaptionTable *caption_table);
-void       nautilus_caption_table_resize             (NautilusCaptionTable *caption_table,
+guint      ammonite_caption_table_get_num_rows       (AmmoniteCaptionTable *caption_table);
+void       ammonite_caption_table_resize             (AmmoniteCaptionTable *caption_table,
 						      guint                 num_rows);
 
 BEGIN_GNOME_DECLS
 
-#endif /* NAUTILUS_CAPTION_TABLE_H */
+#endif /* AMMONITE_CAPTION_TABLE_H */
 
 
