@@ -1,4 +1,4 @@
-/* $Id: digest.c,v 1.16 2000/12/06 01:21:32 mfleming Exp $
+/* $Id: digest.c,v 1.17 2001/02/23 12:23:35 seth Exp $
  * 
  * Copyright (C) 2000 Eazel, Inc
  *
@@ -163,7 +163,7 @@ digest_init ( const char *username, const char *passwd , char *authn_header )
 
 	log ("Got header: %s", authn_header);
 
-	for ( ; *current && isspace (*current); current++ ) ;
+	for ( ; *current && isspace ((guchar) *current); current++ ) ;
 
 	if ( ! STRING_STARTS_WITH (current, "Digest")) {
 		log ("Received WWW-Authenticate, but isn't 'Digest'");
@@ -173,13 +173,13 @@ digest_init ( const char *username, const char *passwd , char *authn_header )
 
 	current += strlen ("Digest");
 
-	if ( ! isspace (*current) ) {
+	if ( ! isspace ((guchar) *current) ) {
 		log ("Received WWW-Authenticate, but isn't 'Digest'");
 		success = FALSE;
 		goto error;
 	}
 
-	for ( ; *current && isspace (*current); current++ ) ;
+	for ( ; *current && isspace ((guchar) *current); current++ ) ;
 
 	while ( ! http_parse_authn_header ( &current, &key, &value ) ) {
 		if ( STRING_CASE_EQUALS (key, "realm") && value ) {
@@ -191,7 +191,7 @@ digest_init ( const char *username, const char *passwd , char *authn_header )
 			have_algorithm = TRUE;
 		} else if ( STRING_CASE_EQUALS (key, "qop" ) && value ) {
 			char *tmp;
-			if ( ! ( (tmp = strstr (value, "auth") ) && ( '\0' == tmp[4] || isspace (tmp[4]) ) ) ) {
+			if ( ! ( (tmp = strstr (value, "auth") ) && ( '\0' == tmp[4] || isspace ((guchar) tmp[4]) ) ) ) {
 				log ("Incompatible WWW-Authenticate header");
 				success = FALSE;
 				goto error;
