@@ -1,4 +1,4 @@
-/* $Id: http-connection.c,v 1.25 2001/02/28 01:16:24 mfleming Exp $
+/* $Id: http-connection.c,v 1.26 2001/03/26 01:07:21 jirka Exp $
  * 
  * Copyright (C) 2000 Eazel, Inc
  *
@@ -397,8 +397,8 @@ http_connection_connect (
 		if ( NULL != fm_mirror_arg ) {
 			socket_set_mirrors (server_socket, fm_mirror_arg, to_mirror_arg);
 		} else {
-			fm_mirror_filename = g_strdup_printf ("%s/ep-%ld-%d-fm-http-req.log", config.mirror_log_dir, (long int)getpid(), http_req_count);
-			to_mirror_filename = g_strdup_printf ("%s/ep-%ld-%d-to-http-req.log", config.mirror_log_dir, (long int)getpid(), http_req_count);
+			fm_mirror_filename = g_strdup_printf ("%s/ep-%ld-%ld-fm-http-req.log", config.mirror_log_dir, (long int)getpid(), (long int)http_req_count);
+			to_mirror_filename = g_strdup_printf ("%s/ep-%ld-%ld-to-http-req.log", config.mirror_log_dir, (long int)getpid(), (long int)http_req_count);
 			fm_mirror = fopen (fm_mirror_filename, "w");
 			to_mirror = fopen (to_mirror_filename, "w");
 			socket_set_mirrors (server_socket, fm_mirror, to_mirror);
@@ -497,8 +497,8 @@ http_connection_connect_submit (
 		header_list  = 	g_list_prepend(
 					header_list, 
 					g_strdup_printf (
-						"Content-Length: %u", 
-						submit_state->cb_submit_body
+						"Content-Length: %lu", 
+						(unsigned long int)submit_state->cb_submit_body
 					)
 				);
 	}
