@@ -1,4 +1,4 @@
-/* $Id: proxy.c,v 1.39 2001/02/28 01:16:24 mfleming Exp $
+/* $Id: proxy.c,v 1.40 2001/03/31 01:23:35 mfleming Exp $
  *
  * A trivial proxy server for relaying Eazel HTTP connections.  Sets up
  * initial config options, daemonizes if necessary, and then stays in a
@@ -118,7 +118,7 @@ int gl_opt_no_ssl = 0;
 gboolean gl_gconf_ssl_disabled = FALSE;
 char *gl_gconf_ssl_cert = NULL;
 char *gl_gconf_ssl_cert_dir = NULL;
-
+char *gl_opt_proxy_auth = NULL;
 
 static const struct poptOption popt_options[] = {
 	{"target-path", 't', POPT_ARG_STRING, NULL, 't', "force all web pages to a specific site", "url"},
@@ -146,6 +146,7 @@ static const struct poptOption popt_options[] = {
 #ifndef SIMPLE_PROXY
 	{NULL, '\0', POPT_ARG_INCLUDE_TABLE, oaf_popt_options, 0, "OAF options", NULL},
 #endif /* SIMPLE_PROXY */
+	{"proxy-auth", 'a', POPT_ARG_STRING, &gl_opt_proxy_auth, 'a', "Enable basic proxy authentication", "user:password"},
 	POPT_AUTOHELP
 	{NULL, 'h', POPT_ARG_NONE | POPT_ARGFLAG_DOC_HIDDEN, NULL, 'h', "", NULL},
 	{NULL, '\0', 0, NULL, 0, NULL}
@@ -327,7 +328,7 @@ simple_proxy_request_cb (gpointer user_data,
 		return NULL;
 	}
 
-	destination_node = g_list_find_custom (*p_header_list, "Destination: ", util_glist_string_starts_with);
+	destination_node = g_list_find_custom (*p_header_list, "Destination: ", util_glist_string_starts_with_case_insensitive);
 
 	if (destination_node) {
 		char *new_header;
@@ -363,6 +364,57 @@ simple_proxy_request_cb (gpointer user_data,
 	return NULL;
 }
 
+/* If the user has specified --proxy-auth, apply it */
+static int
+simple_proxy_auth_cb (	gpointer user_data, 
+			unsigned short port, 
+			HTTPRequestLine *request, 
+			GList **p_header_list,
+			/*OUT*/ char **p_status_text,
+			/*OUT*/ GList **p_ret_header_list)
+{
+	GList *auth_header_node;
+	char *encoded_credentials = NULL;
+
+	if ( NULL == gl_opt_proxy_auth ) {
+		return 200;
+	}
+
+	auth_header_node = g_list_find_custom (*p_header_list, "Proxy-Authorization: ", util_glist_string_starts_with_case_insensitive);
+
+	if (NULL != auth_header_node) {
+		gchar **header_split;
+		encoded_credentials = util_base64_encode (gl_opt_proxy_auth);
+
+		header_split = g_strsplit ((char *) auth_header_node->data, " ", 3);
+
+		if (NULL != header_split[0]
+			&& NULL != header_split[1] 
+			&& NULL != header_split[2]
+			&& 0==strcasecmp (header_split[1], "Basic")
+			&& 0==strcasecmp (header_split[2], encoded_credentials))
+		{
+			/* Remove the Proxy-Authorization header node */
+			g_free (auth_header_node->data); 
+			*p_header_list = g_list_remove_link (*p_header_list, auth_header_node);
+			g_list_free (auth_header_node);		
+
+
+			g_strfreev (header_split);
+			g_free (encoded_credentials);
+			return 200;
+		}
+		g_strfreev (header_split);
+		g_free (encoded_credentials);
+	}
+
+	/* Otherwise, demand credentials */
+	/* Note that excluding "realm" will break Mozilla (at least 0.8) */
+	*p_status_text = g_strdup ("Proxy Authentication Required");
+	*p_ret_header_list = g_list_prepend (*p_ret_header_list, g_strdup ("Proxy-Authenticate: Basic realm=\"ammonite\""));
+	return 407; 	/* 407 Proxy Authentication Required */
+}
+
 int main (int argc, 
 	  char **argv)
 {
@@ -572,7 +624,8 @@ int main (int argc,
 		static const ProxyCallbackInfo callbacks = {
 			simple_proxy_request_cb,
 			NULL,
-			NULL
+			NULL,
+			simple_proxy_auth_cb
 		};
 
 		port = proxy_listen (config.local_host, config.local_port, NULL, &callbacks, NULL);
