@@ -1,4 +1,4 @@
-/* $Id: request.h,v 1.7 2000/08/01 02:28:59 robey Exp $
+/* $Id: request.h,v 1.8 2000/11/15 22:08:35 robey Exp $
  *
  * Copyright (C) 2000  Eazel, Inc
  *
@@ -27,7 +27,8 @@
 /* proxy_tunnel functions */
 int socket_connect_proxy_tunnel(Socket *sock, const char *name, int port, gboolean setup_ssl, SocketConnectFn connectfn);
 
-unsigned short proxy_listen (unsigned short port, gpointer user_data, const ProxyCallbackInfo * callbacks, const char *target_path);
+unsigned short proxy_listen (const char *address, unsigned short port, gpointer user_data,
+			     const ProxyCallbackInfo * callbacks, const char *target_path);
 void proxy_listen_close (unsigned short port); 
 
 #endif /*_REQUEST_H_*/
