@@ -1,4 +1,4 @@
-/* $Id: session.h,v 1.7 2001/01/16 21:30:08 mfleming Exp $
+/* $Id: session.h,v 1.8 2001/03/31 01:23:35 mfleming Exp $
  *
  * Copyright (C) 2000  Eazel, Inc
  *
@@ -32,18 +32,34 @@ typedef struct {
 	char *version;	/* 1.0 */
 } HTTPRequestLine;
 
+/* Returns the connection_user_data passed to ProxyReponseCb */
+/* FIXME there's no way to inform the client that a connection was dropped prior to
+ * receiving a response
+ */
 typedef gpointer (*ProxyRequestCb) (gpointer user_data, unsigned short port, HTTPRequestLine *request,
 				GList **p_header_list);
 typedef void (*ProxyResponseCb) (gpointer user_data, gpointer connection_user_data, unsigned short port, 
 				 char **p_status_line, GList **p_header_list);
 typedef void (*ProxyCloseCb) (gpointer user_data, unsigned short port);
 
+/* Called to authenticate a connecting peer
+ * Return should either be 200 if the connection shoudl be allowed, or an
+ * approprate error code (with p_status_text and p_ret_header_list set
+ * appropriately)
+ */
+typedef int (*ProxyAuthCb) (gpointer user_data, unsigned short port,
+			    HTTPRequestLine *request, GList **p_header_list,
+			    /*OUT*/ char **p_status_text,
+			    /*OUT*/ GList **p_ret_header_list);
+
 typedef void (*ProxyFreezeCb) (gpointer freeze_user_data);
 
+
 typedef struct ProxyCallbackInfo {
 	ProxyRequestCb request_cb;
 	ProxyResponseCb response_cb;
 	ProxyCloseCb close_cb;
+	ProxyAuthCb auth_cb;
 } ProxyCallbackInfo;
 
 typedef enum {
