@@ -1,4 +1,4 @@
-/* $Id: sock.c,v 1.30 2000/10/30 21:08:40 mfleming Exp $
+/* $Id: sock.c,v 1.32 2000/11/28 03:02:40 mfleming Exp $
  *
  * Handles incoming request callbacks, buffers headers, and passes
  * the request on to the upstream server.
@@ -330,6 +330,11 @@ socket_destroy(Socket *sock)
 	}
 #endif
 
+#ifdef HAVE_OPENSSL
+	SSL_free (sock->ssl_handle);
+#endif
+
+
         if (socket_chain == sock) {
                 socket_chain = sock->next;
         } else {
@@ -459,8 +464,10 @@ socket_write(Socket *sock, char *data, int datalen)
 	g_return_val_if_fail(!(sock->flags & (SOCKET_FLAG_LISTEN | SOCKET_FLAG_CONNECTING |
 					      SOCKET_FLAG_CLOSING)), 0);
 
-	if (sock->out_buffer->used > 0) {
-		/* already buffering output to this socket -- just append */
+	if ((sock->flags & SOCKET_FLAG_CORK) || sock->out_buffer->used > 0) {
+		/* either we're in cork mode or already have output queued to this socket
+		 *  -- just append
+		 */
 		return sockbuf_append (sock->out_buffer, data, datalen);
 	}
 
@@ -812,8 +819,10 @@ socket_glib_poll_func (GPollFD *ufds, guint nfds, gint timeout)
 	                    (sock->in_buffer->used < sock->in_buffer->size)) {
 				s_poll_fds[i].events |= POLLIN;
 			}		
-			if ((sock->flags & SOCKET_FLAG_CONNECTING) ||
-	                    (sock->out_buffer->used > 0)) {
+			if ((sock->flags & SOCKET_FLAG_CONNECTING)
+	                    || ((sock->out_buffer->used > 0)
+	                    	&& !(sock->flags & SOCKET_FLAG_CORK))) {
+
 				s_poll_fds[i].events |= POLLOUT;
 			}
 		
@@ -1000,6 +1009,17 @@ socket_get_data(Socket *sock)
 	return sock->data;
 }
 
+void
+socket_cork (Socket *sock)
+{
+	sock->flags |= SOCKET_FLAG_CORK;
+}
+
+void socket_uncork (Socket *sock)
+{
+	sock->flags &= ~SOCKET_FLAG_CORK;
+}
+
 void
 socket_get_byte_counts(Socket *sock, guint32 *read, guint32 *written)
 {
